==> kubernetes-model-1.0.68-sources.jar: annotations/io/fabric8/openshift/api/model/RouteTargetReferenceFluentImpl.java <==
package io.fabric8.openshift.api.model;

import java.lang.Integer;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;
import javax.validation.constraints.NotNull;

public class RouteTargetReferenceFluentImpl<A extends RouteTargetReferenceFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements RouteTargetReferenceFluent<A>{

    private String kind;
    private String name;
    private Integer weight;

    public RouteTargetReferenceFluentImpl(){
    }
    public RouteTargetReferenceFluentImpl(RouteTargetReference instance){
            this.withKind(instance.getKind()); 
            this.withName(instance.getName()); 
            this.withWeight(instance.getWeight()); 
    }

    public String getKind(){
            return this.kind;
    }

    public A withKind(String kind){
            this.kind=kind; return (A) this;
    }

    public Boolean hasKind(){
            return this.kind != null;
    }

    public String getName(){
            return this.name;
    }

    public A withName(String name){
            this.name=name; return (A) this;
    }

    public Boolean hasName(){
            return this.name != null;
    }

    public Integer getWeight(){
            return this.weight;
    }

    public A withWeight(Integer weight){
            this.weight=weight; return (A) this;
    }

    public Boolean hasWeight(){
            return this.weight != null;
    }

    public boolean equals(Object o){
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;
            if (!super.equals(o)) return false;
            RouteTargetReferenceFluentImpl that = (RouteTargetReferenceFluentImpl) o;
            if (kind != null ? !kind.equals(that.kind) :that.kind != null) return false;
            if (name != null ? !name.equals(that.name) :that.name != null) return false;
            if (weight != null ? !weight.equals(that.weight) :that.weight != null) return false;
            return true;
    }




}

==> kubernetes-model-4.1.1-sources.jar: annotations/io/fabric8/openshift/api/model/RouteTargetReferenceFluentImpl.java <==
package io.fabric8.openshift.api.model;

import java.lang.Integer;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;
import javax.validation.constraints.NotNull;

public class RouteTargetReferenceFluentImpl<A extends RouteTargetReferenceFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements RouteTargetReferenceFluent<A>{

    private String kind;
    private String name;
    private Integer weight;

    public RouteTargetReferenceFluentImpl(){
    }
    public RouteTargetReferenceFluentImpl(RouteTargetReference instance){
            this.withKind(instance.getKind()); 
            this.withName(instance.getName()); 
            this.withWeight(instance.getWeight()); 
    }

    public String getKind(){
            return this.kind;
    }

    public A withKind(String kind){
            this.kind=kind; return (A) this;
    }

    public Boolean hasKind(){
            return this.kind != null;
    }

    public String getName(){
            return this.name;
    }

    public A withName(String name){
            this.name=name; return (A) this;
    }

    public Boolean hasName(){
            return this.name != null;
    }

    public Integer getWeight(){
            return this.weight;
    }

    public A withWeight(Integer weight){
            this.weight=weight; return (A) this;
    }

    public Boolean hasWeight(){
            return this.weight != null;
    }

    public A withNewWeight(String arg1){
            return (A)withWeight(new Integer(arg1));
    }

    public A withNewWeight(int arg1){
            return (A)withWeight(new Integer(arg1));
    }

    public boolean equals(Object o){
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;
            if (!super.equals(o)) return false;
            RouteTargetReferenceFluentImpl that = (RouteTargetReferenceFluentImpl) o;
            if (kind != null ? !kind.equals(that.kind) :that.kind != null) return false;
            if (name != null ? !name.equals(that.name) :that.name != null) return false;
            if (weight != null ? !weight.equals(that.weight) :that.weight != null) return false;
            return true;
    }




}
